@@ -15,7 +15,7 @@ from codebased.settings import Settings
 from codebased.stats import STATS
 from codebased.tui import Codebased
 
-VERSION = "0.4.9"
+VERSION = "0.4.18"
 
 cli = typer.Typer(
     name="Codebased CLI",
@@ -119,7 +119,10 @@ def search(
         rebuild_faiss_index=rebuild_faiss_index,
         cached_only=cached_only,
         query=query,
-        background=background,
+        # We gather the set of gitignore files during startup and don't specially cache these.
+        # So if we ran the background worker without gathering the .gitignore files, we would not properly ignore
+        # changed files.
+        background=background and not cached_only,
         stats=stats,
         semantic=semantic,
         full_text_search=full_text,
@@ -148,7 +151,7 @@ def search(
             thread.start()
         if flags.query:
             results, times = search_once(dependencies, flags)
-            print_results(config, results)
+            print_results(config, flags, results)
         else:
             Codebased(flags=flags, config=config, dependencies=dependencies).run()
     finally:
